#
# spec file for package libvoikko
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
Name:           libvoikko
Version:        4.3.2
Release:        2.7
Summary:        Library of free natural language processing tools
License:        GPL-2.0-or-later
Group:          Productivity/Text/Spell
URL:            https://voikko.puimula.org
Source0:        https://www.puimula.org/voikko-sources/%{name}/%{name}-%{version}.tar.gz
Source1:        https://www.puimula.org/voikko-sources/%{name}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source99:       baselibs.conf
BuildRequires:  glib2-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-xml
BuildRequires:  pkgconfig(hfstospell) >= 0.5
%if 0%{?suse_version} < 1500
BuildRequires:  gcc7
BuildRequires:  gcc7-c++
%else
BuildRequires:  gcc >= 7
BuildRequires:  gcc-c++ >= 7
%endif

%description
Libvoikko is a library of free natural language processing tools. It
aims to provide support for languages that are not well served by
other existing free linguistic tools.

The library supports multiple backends, of which VFST and HFST are
enabled in the default build:

 - VFST: Finite state transducer format used for Finnish morphology
   and as an experimental language independent backend.
 - HFST (Helsinki Finite-State Transducer Technology): Supports ZHFST
   speller archives for various languages.
 - Experimental backends: Weighted VFST and Lttoolbox.

Libvoikko provides spell checking, hyphenation, grammar checking and
morphological analysis for Finnish language. Spell checking is
supported for other languages through the HFST backend.

%package -n libvoikko1
Summary:        Library of free natural language processing tools
Group:          System/Libraries
Requires:       malaga-suomi

%description -n libvoikko1
Libvoikko is a library of free natural language processing tools. It
aims to provide support for languages that are not well served by
other existing free linguistic tools.

The library supports multiple backends, of which VFST and HFST are
enabled in the default build:

 - VFST: Finite state transducer format used for Finnish morphology
   and as an experimental language independent backend.
 - HFST (Helsinki Finite-State Transducer Technology): Supports ZHFST
   speller archives for various languages.
 - Experimental backends: Weighted VFST and Lttoolbox.

Libvoikko provides spell checking, hyphenation, grammar checking and
morphological analysis for Finnish language. Spell checking is
supported for other languages through the HFST backend.

%package devel
Summary:        Library of free natural language processing tools
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libvoikko1 = %{version}

%description devel
Libvoikko is a library of free natural language processing tools. It
aims to provide support for languages that are not well served by
other existing free linguistic tools.

This package contains the files needed to build or develop applications
that use Voikko.

%package -n voikkospell
Summary:        Test program for Voikko spell checker
Group:          Productivity/Text/Spell
Requires:       libvoikko1 = %{version}

%description -n voikkospell
Libvoikko is a library of free natural language processing tools. It
aims to provide support for languages that are not well served by
other existing free linguistic tools.

This package contains a test program for using Voikko spell checker.

%package -n     python3-libvoikko
Summary:        Python interface to %{name}
Group:          Development/Libraries/Python
Requires:       libvoikko1 = %{version}-%{release}
BuildArch:      noarch

%description -n python3-libvoikko
Libvoikko is a library of free natural language processing tools. It
aims to provide support for languages that are not well served by
other existing free linguistic tools.

This package contains a Python interface to libvoikko. This module
can be used to perform various natural language analysis tasks on text.

%prep
%setup -q

%build
%if 0%{?suse_version} < 1500
export CC="gcc-7"
export CXX="g++-7"
%endif
%configure \
	--disable-silent_rules \
	--disable-static \
	--with-dictionary-path=%{_libexecdir}/voikko:%{_datadir}/voikko
%make_build

%check
%make_build check || :

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

install -d %{buildroot}/%{python3_sitelib}
install -pm 0644 python/libvoikko.py %{buildroot}/%{python3_sitelib}/

%post -n libvoikko1 -p /sbin/ldconfig
%postun -n libvoikko1 -p /sbin/ldconfig

%files -n libvoikko1
%license COPYING
%doc ChangeLog README
%{_libdir}/*.so.*

%files -n voikkospell
%{_bindir}/*
%{_mandir}/man?/*%{ext_man}

%files devel
%{_includedir}/libvoikko
%{_libdir}/*.so
%{_libdir}/pkgconfig/libvoikko.pc

%files -n python3-libvoikko
%{python3_sitelib}/*

%changelog
* Mon Aug  7 2023 Fridrich Strba <fstrba@suse.com>
- Fix build on older distributions by requiring gcc/g++ >= 7
* Sat Jul  1 2023 Dirk Müller <dmueller@suse.com>
- update to 4.3.2:
  * Update C++ standard from C++11 to C++14.
  * Compilation fixes for recent versions of GCC and Emscripten.
  * Small fixes to JS API and Finnish grammar checker
* Tue Apr  6 2021 Timo Jyrinki <tjyrinki@suse.com>
- Update to version 4.3.1
  * Improve performance of Finnish VFST backend by about 4 %%. Thanks to Juha Komulainen
    / Evident Solutions Oy for the optimization idea.
  * Add TypeScript typings, thanks to Niilo Ursin.
  * Python wrapper:
  * Allow native library to be found on Windows with Python 3.8 and later.
  * Add official pip packaging.
  * Various build fixes related to for example new Autoconf and Emscripten versions.
* Sat Jan  4 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop explicit requires for full python3 package, python3-base
  pulled in by python3-xml is sufficient.
- Require minimum version for pkgconfig(hfstospell), >= 0.5
* Thu Oct 31 2019 Timo Jyrinki <tjyrinki@suse.com>
- Update to version 4.3
  * New API function voikkoGetAttributeValues to list possible values for an analysis attribute.
  * Improved spelling correction for Finnish words containing a hyphen.
  * Improvements for Common Lisp interface.
  * Fix compilation of JavaScript port on MacOS and with latest Emscripten.
* Wed Feb 27 2019 Timo Jyrinki <tjyrinki@suse.com>
- Update to version 4.2
  * Support for Malaga dictionary format removed
  * hfst-ospell dependency updated
  * Java, Python, Javascript wrapper improvements
- Drop libvoikko-hfst-namespace.patch
* Mon Apr 23 2018 tchvatal@suse.com
- Add patch to build with new hfst-ospell:
  * libvoikko-hfst-namespace.patch
* Thu Oct  5 2017 jengelh@inai.de
- Stop mixing %%buildroot and $RPM_BUILD_ROOT.
- Drop --with-pic which is a no-op with --disable-static.
* Wed Oct  4 2017 tuukka.pasanen@ilmi.fi
- Added python3 interface package libvoikko which is needed
  by LibreOffice
* Tue Apr 25 2017 tchvatal@suse.com
- Version update to 4.1.1:
  * Various upstream fixes. See ChangeLog
  * Should fix boo#1031331
  * Switch to python3
* Tue Nov 24 2015 p.drouand@gmail.com
- Update to version 3.8
  * Add support for specifying multiple default dictionary locations.
  * Search for dictionares from $HOME/Library/Spelling/voikko on OS X.
  * Tri-licensed the HFST backend
  * Initial support for BCP 47 script subtag.
  * Add support for weighted VFST transducers.
  * Add spelling suggestions to simple VFST spellers by using
  weighted VFST transducers.
  * Autocorrect data is read from VFST transducer in format 5
  dictionaries.
* Wed Aug  5 2015 mpluskal@suse.com
- Add gpg signature
* Thu Nov 13 2014 tchvatal@suse.com
- Version bump to 3.7.1:
  * New dictionary format 5 for VFST.
* Sun Jan 26 2014 tchvatal@suse.com
- Version bump to 3.7:
  * Many bugfixes. See ChangeLog
  * Upstream moved location so update accordingly.
* Tue Feb 28 2012 sbrabec@suse.cz
- Upgrade to version 3.4.1:
  * Many new features, improvements and bug fixes. See ChangeLog
    for details.
  * Handle embedded null input characters in Python and Java
    interfaces. (bnc#699707)
* Mon Jan 30 2012 jengelh@medozas.de
- Ensure pkgconfig symbols are present
* Mon Jan 30 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Tue Dec 27 2011 idonmez@suse.com
- Fix wrong size parameter in memset call
* Wed Nov 23 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Feb 22 2011 vuntz@opensuse.org
- Add missing baselibs.conf.
* Mon Jun 22 2009 pmladek@suse.cz
- Updated to version 2.1:
  * Add option for accepting unfinished paragraphs.
  * Add option VOIKKO_OPT_HYPHENATE_UNKNOWN_WORDS.
  * Add option VOIKKO_OPT_ACCEPT_BULLETED_LISTS_IN_GC.
  * Add support for environment variable VOIKKO_DICTIONARY.
  * Disable character case checks completely within quotations.
  * Disable character case checks if sentence contains a tab character.
  * Disable checks for paragraphs that contain only an URL or some other
    non-standard text.
  * Read replacement suggestions from data/autocorrect/fi_FI.xml.
  * Do not try to check character case for sentences that have been written
    fully in upper case.
  * Allow sentences to start with a digit.
  * Refactoring and porting to C++.
- Added gcc-c++ python python-xml into BuildRequires
- Added libvoikko-2.1-ac-macro-dir.diff, fixed autoreconf to run (sf#2810258)
* Tue Feb  3 2009 crrodriguez@suse.de
- remove "la" files
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Mon Sep  8 2008 sbrabec@suse.cz
- Updated to version 2.0:
  * New API for identifying sentences from text paragraphs.
  * New API for paragraph based grammar checking.
  * New test program voikkogc for testing grammar checker and
    related functionality.
  * Option VOIKKO_OPT_ENCODING has been deprecated.
* Mon Aug  4 2008 ro@suse.de
- do not require non-existent base package in voikkospell
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Fri Jul 25 2008 sbrabec@suse.cz
- New SuSE package based on spec file from Sami Vento (bnc#394355).
